@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # Copyright (C) 2020 CERN.
+# Copyright (C) 2022 Graz University of Technology.
 #
 # Invenio-Cli is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
@@ -25,24 +26,36 @@ def assets():
 
 
 @assets.command()
-@click.option('--no-wipe', '-n', default=False, is_flag=True,
-              help='Do not remove existing assets.')
 @click.option(
-    '--production/--development', '-p/-d', default=False, is_flag=True,
-    help='Production mode copies files. Development mode symlinks files.'
+    "--no-wipe",
+    "-n",
+    default=False,
+    is_flag=True,
+    help="Do not remove existing assets.",
+)
+@click.option(
+    "--production/--development",
+    "-p/-d",
+    default=False,
+    is_flag=True,
+    help="Production mode copies files. Development mode symlinks files.",
+)
+@click.option(
+    "--node-log-file", default=None, help="Specify node log file (default: None)"
 )
 @pass_cli_config
-def build(cli_config, no_wipe, production):
+def build(cli_config, no_wipe, production, node_log_file):
     """Build the static and assets files on the local installation."""
     commands = AssetsCommands(cli_config)
     commands.update_statics_and_assets(
         force=not no_wipe,  # If no_wipe=True, it means force=False
-        flask_env='production' if production else 'development'
+        flask_env="production" if production else "development",
+        log_file=node_log_file,
     )
 
 
 @assets.command()
-@click.argument('path', type=click.Path(exists=True))
+@click.argument("path", type=click.Path(exists=True))
 @pass_cli_config
 def install(cli_config, path):
     """Install and link a React module on the local installation."""
@@ -56,7 +69,7 @@ def install(cli_config, path):
     run_steps(steps, on_fail, on_success)
 
 
-@assets.command('watch')
+@assets.command("watch")
 @pass_cli_config
 def watch_assets(cli_config):
     """Watch assets files on the local installation.
@@ -67,10 +80,9 @@ def watch_assets(cli_config):
     commands.watch_assets()
 
 
-@assets.command('watch-module')
-@click.option('--link', '-l', default=False, is_flag=True,
-              help='Link the module.')
-@click.argument('path', type=click.Path(exists=True))
+@assets.command("watch-module")
+@click.option("--link", "-l", default=False, is_flag=True, help="Link the module.")
+@click.argument("path", type=click.Path(exists=True))
 @pass_cli_config
 def watch_module(cli_config, path, link):
     """Watch a React module on the local installation."""
