@@ -7,12 +7,9 @@
 
 """Invenio module to ease the creation and management of applications."""
 
-import os
-
 import click
 
 from ..helpers.cli_config import CLIConfig
-from ..helpers.process import run_cmd
 
 pass_cli_config = click.make_pass_decorator(CLIConfig, ensure=True)
 
@@ -41,17 +38,3 @@ def run_steps(steps, fail_message, success_message):
             click.secho(message=result.output, fg="green")
     else:
         click.secho(message=success_message, fg="green")
-
-
-def calculate_instance_path(project_dir):
-    """Caclulates instance path based on current venv."""
-    # Ensure pipenv command is running inside the project directory
-    saved_current_path = os.getcwd()
-    os.chdir(project_dir)
-    result = run_cmd(
-            ['pipenv', 'run', 'invenio', 'shell', '--no-term-title',
-                '-c', '"print(app.instance_path, end=\'\')"']
-        )
-    os.chdir(saved_current_path)
-
-    return result.output.strip()
