@@ -27,10 +27,10 @@ class CookiecutterWrapper(object):
     @classmethod
     def extract_template_name(cls, template):
         """Extract template name from a template URL."""
-        name = template.rstrip('/').rpartition("/")[2]
-        git = '.git'
+        name = template.rstrip("/").rpartition("/")[2]
+        git = ".git"
         if name.endswith(git):
-            name = name[:-len(git)]
+            name = name[: -len(git)]
         return name
 
     def __init__(self, flavour, **kwargs):
@@ -60,42 +60,40 @@ class CookiecutterWrapper(object):
             # load values to be passed to cookiecutter from an .invenio file
             self.replay = dict(config[CLIConfig.COOKIECUTTER_SECTION].items())
 
-        if self.flavour.upper() == 'RDM':
+        if self.flavour.upper() == "RDM":
             self.template = (
-                self.template_name or
-                'https://github.com/inveniosoftware/'
-                'cookiecutter-invenio-rdm.git'
+                self.template_name
+                or "https://github.com/inveniosoftware/cookiecutter-invenio-rdm.git"
             )
             self.template_name = self.extract_template_name(self.template)
-            self.checkout = self.checkout or 'v9.0'
+            self.checkout = self.checkout or "v10"
 
     def cookiecutter(self):
         """Wrap cookiecutter call."""
         # build actual kwargs
         cookiecutter_kwargs = {
-            'template': self.template,
+            "template": self.template,
             # NOTE: if template is not a git url, then checkout is ignored
-            'checkout': self.checkout,
+            "checkout": self.checkout,
         }
         if self.config or self.no_input:
-            cookiecutter_kwargs['no_input'] = self.no_input
-            cookiecutter_kwargs['extra_context'] = self.replay
+            cookiecutter_kwargs["no_input"] = self.no_input
+            cookiecutter_kwargs["extra_context"] = self.replay
 
         # run cookiecutter
         return cookiecutter(
-            config_file=self.create_and_dump_config_file(),
-            **cookiecutter_kwargs
+            config_file=self.create_and_dump_config_file(), **cookiecutter_kwargs
         )
 
     def create_and_dump_config_file(self):
         """Create a tmp file to store used configuration."""
         if not self.tmp_file:
-            self.tmp_file = tempfile.NamedTemporaryFile(mode='w+')
+            self.tmp_file = tempfile.NamedTemporaryFile(mode="w+")
 
         config = DEFAULT_CONFIG.copy()
         # BUG: when dumping {}, it's read back as a string '{}'
-        config['default_context'] = None
-        config['replay_dir'] = tempfile.gettempdir()
+        config["default_context"] = None
+        config["replay_dir"] = tempfile.gettempdir()
 
         yaml.dump(config, self.tmp_file)
 
